pub struct StartTimestamp(pub OffsetDateTime);Expand description
A timestamp which will be align with the start of a ParsedTimestamp. Meaning, it will
take the minimum value of all omitted components.
Tuple Fields
0: OffsetDateTimeTrait Implementations
Sourceimpl Clone for StartTimestamp
impl Clone for StartTimestamp
Sourcefn clone(&self) -> StartTimestamp
fn clone(&self) -> StartTimestamp
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StartTimestamp
Sourceimpl Debug for StartTimestamp
impl Debug for StartTimestamp
impl Eq for StartTimestamp
Sourceimpl From<StartTimestamp> for OffsetDateTime
impl From<StartTimestamp> for OffsetDateTime
Sourcefn from(value: StartTimestamp) -> Self
fn from(value: StartTimestamp) -> Self
Converts to this type from the input type.
Sourceimpl From<StartTimestamp> for SystemTime
impl From<StartTimestamp> for SystemTime
Sourcefn from(value: StartTimestamp) -> Self
fn from(value: StartTimestamp) -> Self
Converts to this type from the input type.
Sourceimpl FromStr for StartTimestamp
impl FromStr for StartTimestamp
Sourceimpl PartialEq for StartTimestamp
impl PartialEq for StartTimestamp
impl StructuralPartialEq for StartTimestamp
Sourceimpl TryFrom<ParsedTimestamp> for StartTimestamp
impl TryFrom<ParsedTimestamp> for StartTimestamp
Sourcetype Error = ConversionError
type Error = ConversionError
The type returned in the event of a conversion error.